#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 universe-base
version:              1.1.4
visibility:           public
id:                   universe-base-1.1.4-9HJpwtn36WJHDsGT0LjRzz
key:                  universe-base-1.1.4-9HJpwtn36WJHDsGT0LjRzz
license:              BSD-3-Clause
copyright:            2014 Daniel Wagner
maintainer:           me@dmwit.com
author:               Daniel Wagner
homepage:             https://github.com/dmwit/universe
synopsis:             A class for finite and recursively enumerable types.
description:
    A class for finite and recursively enumerable types and some helper functions for enumerating them.

    @
    class Universe a where universe :: [a]
    class Universe a => Finite a where universeF :: [a]; universeF = universe
    @

    This is slim package definiting only the type-classes and instances
    for types in GHC boot libraries.
    For more instances check @universe-instances-*@ packages.

category:             Data
abi:                  3fc499852c0094cd71afb95234a8c2c4
exposed:              True
exposed-modules:
    Data.Universe.Class Data.Universe.Generic Data.Universe.Helpers

import-dirs:          /usr/lib/ghc-9.6.6/site-local/universe-base-1.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/universe-base-1.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/universe-base-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-universe-base
hs-libraries:         HSuniverse-base-1.1.4-9HJpwtn36WJHDsGT0LjRzz
depends:
    base-4.18.2.1 containers-0.6.7 tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-universe-base/html/universe-base.haddock

haddock-html:         /usr/share/doc/haskell-universe-base/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

